/*
 * Element.java
 *
 * Created on 31 de julio de 2002, 11:13
 */

package pgclibrary.treeObjects;
import pgclibrary.objects.*;

/**
 *
 * @author  nestor
 */
public class Element extends TreeInfo {
    DBObject source = null;
    
    /** Creates a new instance of Element */
    public Element(TreeInfo _owner, DBObject _source) {
        super(_owner);
        source = _source;
        removeAllProperties();
    }
    
    public void rebuildProperties() {
        source.refresh();
        removeAllProperties();
    }

    public String toString(){
        return source.getName();
    }
    
    // ------SET AND GET--------
    public Object getOID() {
        return source.getName();
    }
    public DBObject getSource(){
        return source;
    }
}
